use v6-alpha;

use Bar;

class FooBar is ::Bar;

method foobar { "foobar" }
